Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

### - c -

- calculate_chain() : stan::math
- categorical_log() : stan::math
- categorical_logit_log() : stan::math
- categorical_rng() : stan::math
- cauchy_ccdf_log() : stan::math
- cauchy_cdf() : stan::math
- cauchy_cdf_log() : stan::math
- cauchy_log() : stan::math
- cauchy_rng() : stan::math
- cbrt() : stan::math
- ceil() : stan::math
- check_bounded() : stan::math
- check_cholesky_factor() : stan::math
- check_cholesky_factor_corr() : stan::math
- check_column_index() : stan::math
- check_consistent_size() : stan::math
- check_consistent_sizes() : stan::math
- check_corr_matrix() : stan::math
- check_cov_matrix() : stan::math
- check_equal() : stan::math
- check_finite() : stan::math
- check_greater() : stan::math
- check_greater_or_equal() : stan::math
- check_ldlt_factor() : stan::math
- check_less() : stan::math
- check_less_or_equal() : stan::math
- check_lower_triangular() : stan::math
- check_matching_dims() : stan::math
- check_matching_sizes() : stan::math
- check_multiplicable() : stan::math
- check_nonnegative() : stan::math
- check_nonzero_size() : stan::math
- check_not_nan() : stan::math
- check_ordered() : stan::math
- check_pos_definite() : stan::math
- check_pos_semidefinite() : stan::math
- check_positive() : stan::math
- check_positive_finite() : stan::math
- check_positive_ordered() : stan::math
- check_positive_size() : stan::math
- check_range() : stan::math
- check_row_index() : stan::math
- check_simplex() : stan::math
- check_size_match() : stan::math
- check_spsd_matrix() : stan::math
- check_square() : stan::math
- check_std_vector_index() : stan::math
- check_symmetric() : stan::math
- check_unit_vector() : stan::math
- check_vector() : stan::math
- chi_square_ccdf_log() : stan::math
- chi_square_cdf() : stan::math
- chi_square_cdf_log() : stan::math
- chi_square_log() : stan::math
- chi_square_rng() : stan::math
- cholesky_corr_constrain() : stan::math
- cholesky_corr_free() : stan::math
- cholesky_decompose() : stan::math
- cholesky_factor_constrain() : stan::math
- cholesky_factor_free() : stan::math
- col() : stan::math
- cols() : stan::math
- columns_dot_product() : stan::math
- columns_dot_self() : stan::math
- corr_constrain() : stan::math
- corr_free() : stan::math
- corr_matrix_constrain() : stan::math
- corr_matrix_free() : stan::math
- cos() : stan::math
- cosh() : stan::math
- cov_matrix_constrain() : stan::math
- cov_matrix_constrain_lkj() : stan::math
- cov_matrix_free() : stan::math
- cov_matrix_free_lkj() : stan::math
- crossprod() : stan::math
- csr_extract_u() : stan::math
- csr_extract_v() : stan::math
- csr_extract_w() : stan::math
- csr_matrix_times_vector() : stan::math
- csr_to_dense_matrix() : stan::math
- csr_u_to_z() : stan::math
- cumulative_sum() : stan::math
- cvodes_check_flag() : stan::math
- cvodes_set_options() : stan::math
- cvodes_silent_err_handler() : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.